# @gradio/spaces-test

## 0.0.1

### Dependency updates

- @gradio/client@0.18.0
- @gradio/form@0.1.16

## 0.0.1

### Dependency updates

- @gradio/client@0.17.0
- @gradio/form@0.1.15

## 0.0.1

### Dependency updates

- @gradio/theme@0.2.2
- @gradio/client@0.16.0
- @gradio/form@0.1.14

## 0.0.1

### Dependency updates

- @gradio/theme@0.2.1
- @gradio/client@0.15.1
- @gradio/form@0.1.13

## 0.0.1

### Dependency updates

- @gradio/client@0.15.0

## 0.0.1

### Dependency updates

- @gradio/form@0.1.12

## 0.0.1

### Dependency updates

- @gradio/form@0.1.11

## 0.0.1

### Dependency updates

- @gradio/client@0.14.0

## 0.0.1

### Dependency updates

- @gradio/client@0.13.0